<?php
namespace FiloBlu\Rma\Block\Adminhtml\System\Config;

class Reason extends \Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray
{
    
    /**
     * @var \Magento\Eav\Model\Config $eav_config,
     */
    protected $eav_config;


    /**
     * Constructor
     * 
     * @param \Magento\Eav\Model\Config $eav_config
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \FiloBlu\Rma\Api\Model\Config\Reader $reader
     * @param array $data
     */
    public function __construct(        
        \Magento\Eav\Model\Config $eav_config,
        \Magento\Backend\Block\Template\Context $context, 
        \FiloBlu\Rma\Api\Model\Config\Reader $reader,
        array $data = []
    ) {
        $this->eav_config = $eav_config;
        $this->reader = $reader;
        parent::__construct($context, $data);
    }
    
    
    protected function _prepareToRender()
    {
        
        $attribute = $this->eav_config->getAttribute('rma_item', 'reason');
        $options = $attribute->getSource()->getAllOptions();

        $isVisible =[
                        ['value'=>'*','label'=>__('-- Select --')],
                        ['value'=>0,'label'=>'No'],
                        ['value'=>1,'label'=>'Yes']
                    ];
        $brand_reasons = array();
        $standard_reasons = array();
        $standard_reasons_config = $this->reader->read();
        foreach($standard_reasons_config as $reason):
            $id=$reason['id'];
            $standard_reasons[] = array('value' => $reason['id'], 'label' => $reason['standard_name']);
        endforeach;
        
        foreach($options as $option):
            if($option['value']):
                $brand_reasons[] = array('value' => $option['value'], 'label' => $option['label']);
            endif;
        endforeach;
        
        array_unshift($brand_reasons,  array('value' => '*', 'label' => __('-- Select --')));  
        array_unshift($standard_reasons,  array('value' => '*', 'label' => __('-- Select --'))); 

        $brand_reasons_block=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','brand_reason'))
                        ->setName($this->_getCellInputElementName('brand_reason'))
                        ->setClass('select')
                        ->setOptions($brand_reasons);

        $this->addColumn('brand_reason', array(
            'label' => __('Brand Reason'),
            'renderer' => $brand_reasons_block
        ));
        
        $standard_reasons_block=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
                        ->setId($this->_getCellInputElementId('<%- _id %>','standard_reason'))
                        ->setName($this->_getCellInputElementName('standard_reason'))
                        ->setClass('select')
                        ->setOptions($standard_reasons);

        $is_visible_block=$this->getLayout()->createBlock('Magento\Framework\View\Element\Html\Select')
            ->setId($this->_getCellInputElementId('<%- _id %>','is_visible'))
            ->setName($this->_getCellInputElementName('is_visible'))
            ->setClass('select')
            ->setOptions($isVisible);
        
        $this->addColumn('standard_reason', array(
            'label' => __('Standard Reason'),
            'renderer' => $standard_reasons_block
        ));

        $this->addColumn('is_visibile', array(
            'label' => __('Visible At FE'),
            'renderer' => $is_visible_block
        ));

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add new mapping');
    }
 
   
}
